@@ -1,6 +1,6 @@
 from typing import TypedDict
 from typing import List
-
+from enum import Enum
 
 class BringList(TypedDict):
     """A list class. Represents a single list."""
@@ -55,4 +55,17 @@ class BringItemsResponse(TypedDict):
 
 class BringListItemsDetailsResponse(List[BringListItemDetails]):
     """A response class of a list of item details."""
-    pass
\ No newline at end of file
+    pass
+
+class BringNotificationType(Enum):
+    """Notification type
+    
+    GOING_SHOPPING: "I'm going shopping! - Last chance for adjustments"
+    CHANGED_LIST: "List changed - Check it out"
+    SHOPPING_DONE: "Shopping done - you can relax"
+    URGENT_MESSAGE: "Breaking news - Please get {itemName}! 
+    """
+    GOING_SHOPPING = "GOING_SHOPPING"
+    CHANGED_LIST = "CHANGED_LIST"
+    SHOPPING_DONE = "SHOPPING_DONE"
+    URGENT_MESSAGE = "URGENT_MESSAGE"
\ No newline at end of file
