@@ -1,6 +1,7 @@
 import sys
 sys.path.append('src')
 from python_bring_api.bring import Bring
+from python_bring_api.types import BringNotificationType
 
 # Create Bring instance with email and password
 bring = Bring("e.ball227@gmail.com", "SHSFJvKNOA*U4a5")
@@ -24,4 +25,10 @@ bring.getAllItemDetails(lists[0]['listUuid'])
 bring.updateItem(lists[0]['listUuid'], 'Milk', 'high fat')
 
 # Remove an item from a list
-bring.removeItem(lists[0]['listUuid'], 'Milk')
\ No newline at end of file
+bring.removeItem(lists[0]['listUuid'], 'Milk')
+
+# Add an item to recents
+bring.completeItem(lists[0]['listUuid'], 'Bread')
+
+# Notify other users
+bring.notify(lists[0]['listUuid'], BringNotificationType.CHANGED_LIST)
\ No newline at end of file
